package chat

import (
	"fmt"
	"server/datacenter/chat_db"
	agentmanager "server/game/agentManager"
	"server/msg"

	"github.com/name5566/leaf/gate"
)

func SendChatMsg(args []interface{}) {
	m := args[0].(*msg.ReqSendChatMsg)
	a := args[1].(gate.Agent)
	FromUserInfo := a.UserData().(*msg.UserInfo)
	FromUserID := FromUserInfo.UserId
	SessionID := generatePrivateSessionID(m.ToUserid, FromUserID)
	chatMsg, err := chat_db.SendMessage(m.ToUserid, SessionID, []byte(m.Content))
	if err != nil {
		a.WriteMsg(&msg.ResSendChatMsg{
			Success: false,
			ErrMsg: &msg.MsgError{
				ErrorCode: 101,
				ErrorMsg:  err.Error(),
			},
		})

	} else {
		ToAgent := agentmanager.GetAgentByUserID(m.ToUserid)
		if ToAgent != nil {
			ToAgent.WriteMsg(&msg.RecvChatMsg{Info: chatMsg})
		}
	}

}

func GetChatHistory(args []interface{}) {
	m := args[0].(*msg.ReqChatHistory)
	a := args[1].(gate.Agent)
	FromUserInfo := a.UserData().(*msg.UserInfo)
	FromUserID := FromUserInfo.UserId
	SessionID := generatePrivateSessionID(m.ToUserid, FromUserID)
	chat_list, err := chat_db.GetHistoryMessages(SessionID, m.LastMsgid, 50)
	if err != nil {
		a.WriteMsg(&msg.ResChatHistory{
			Success: false,
			ErrMsg: &msg.MsgError{
				ErrorCode: 101,
				ErrorMsg:  err.Error(),
			},
		})
	} else {
		a.WriteMsg(&msg.ResChatHistory{
			Success: true,
			List:    chat_list,
		})
	}
}

// 生成私聊会话ID（保证user1和user2顺序无关）
func generatePrivateSessionID(user1, user2 string) string {
	if user1 > user2 {
		return fmt.Sprintf("private_%s_%s", user2, user1)
	}
	return fmt.Sprintf("private_%s_%s", user1, user2)
}
